==> gnome-games-0.99.1.tar.gz: gnome-games-0.99.1/gnome-stones/preferences.h <==
/* gnome-stones - preferences.h
 *
 * Time-stamp: <1998/11/22 15:42:49 carsten>
 *
 * Copyright (C) 1998 Carsten Schaar
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef PREFERENCES_H
#define PREFERENCES_H

#include <config.h>
#include <gnome.h>
#include "types.h"


/*****************************************************************************/
/* Global Variables */

/* This variable specifies the currently played game.  If 'game' is
   equal to 'NULL', than no game is loaded.  */

extern GStonesGame *game;

/* The currently played cave.  This cave must be a cave, that belongs
   to the game 'game'.  */

extern GStonesCave *cave;

/* The data about the player.  */

extern GStonesPlayer *player;

/* You may start a game in different cavs.  'start_cave' decides, in
   which cave the player will start.  */

extern guint start_cave;

/* If you use a joystick as input device, this variable holds the
   device's id.  Setting it to GDK_CORE_POINTER disables the Joystick
   support.  */

extern guint32  joystick_deviceid;
extern gfloat   joystick_switch_level;

/* The game can be in different states.  These state decides, how to
   react if some events occur.  */

typedef enum
{
  STATE_STARTUP,
  STATE_TITLE,
  STATE_CURTAIN,
  STATE_WAITING_TO_START,
  STATE_RUNNING,
  STATE_COUNTDOWN,
} GameState;

extern GameState state;



/*****************************************************************************/


/* Scans a game directory for game files and adds them to an internal
   game list.  */

void
game_directory_scan (const char *directory);



/*****************************************************************************/


/* The following function returns a new preferences dialog box.  */

GtkWidget *
preferences_dialog_new (void);


/* Save preferences.  */

void
preferences_save (void);


/* Restores the preferences from disc.  */

gboolean
preferences_restore (void);



/*****************************************************************************/


/* Discards a session file.  */

void
discard_session_file (const gchar *file);


/* Initialize the session management stuff.  */

void
session_management_init (void);



/*****************************************************************************/


#endif

/* Local Variables: */
/* mode:c */
/* eval:(load-library "time-stamp") */
/* eval:(make-local-variable 'write-file-hooks) */
/* eval:(add-hook 'write-file-hooks 'time-stamp) */
/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
/* End: */

==> gnome-games-1.0.1.tar.gz: gnome-games-1.0.1/gnome-stones/preferences.h <==
/* gnome-stones - preferences.h
 *
 * Time-stamp: <1999/01/17 15:14:36 carsten>
 *
 * Copyright (C) 1998 Carsten Schaar
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef PREFERENCES_H
#define PREFERENCES_H

#include <config.h>
#include <gnome.h>
#include "types.h"


/*****************************************************************************/
/* Global Variables */

/* This variable specifies the currently played game.  If 'game' is
   equal to 'NULL', than no game is loaded.  */

extern GStonesGame *game;

/* The currently played cave.  This cave must be a cave, that belongs
   to the game 'game'.  */

extern GStonesCave *cave;

/* The data about the player.  */

extern GStonesPlayer *player;

/* You may start a game in different cavs.  'start_cave' decides, in
   which cave the player will start.  */

extern guint start_cave;

/* If you use a joystick as input device, this variable holds the
   device's id.  Setting it to GDK_CORE_POINTER disables the Joystick
   support.  */

extern guint32  joystick_deviceid;
extern gfloat   joystick_switch_level;

/* The game can be in different states.  These state decides, how to
   react if some events occur.  */

typedef enum
{
  STATE_STARTUP,
  STATE_TITLE,
  STATE_CURTAIN,
  STATE_WAITING_TO_START,
  STATE_RUNNING,
  STATE_COUNTDOWN,
} GameState;

extern GameState state;



/*****************************************************************************/


/* Scans a game directory for game files and adds them to an internal
   game list.  */

void
game_directory_scan (const char *directory);



/*****************************************************************************/


/* The following opens the preferences dialog box.  */

void
preferences_dialog_show (void);


/* Save preferences.  */

void
preferences_save_global (void);


/* Restores the preferences from disc.  */

gboolean
preferences_restore (void);



/*****************************************************************************/


/* Initialize the session management stuff.  */

void
session_management_init (void);



/*****************************************************************************/


#endif

/* Local Variables: */
/* mode:c */
/* eval:(load-library "time-stamp") */
/* eval:(make-local-variable 'write-file-hooks) */
/* eval:(add-hook 'write-file-hooks 'time-stamp) */
/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
/* End: */
